BottomSheetNavigator class

Inheritance

Properties

addFavoriteSeparator bool
finalinherited
bottomSheetDragHandlerColor Color?
finalinherited
countries List<IsoCode>?
finalinherited
countryCodeStyle TextStyle?
finalinherited
countryNameStyle TextStyle?
finalinherited
defaultSearchInputIconColor Color?
finalinherited
favorites List<IsoCode>?
finalinherited
flagShape BoxShape
finalinherited
flagSize double
finalinherited
hashCode int
The hash code for this object.
no setterinherited
noResultMessage String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics ScrollPhysics?
finalinherited
searchInputDecoration InputDecoration?
finalinherited
searchInputHeight double?
finalinherited
searchInputTextStyle TextStyle?
finalinherited
searchInputWidth double?
finalinherited
showCountryCode bool
finalinherited
showCountryFlag bool
finalinherited
showCountryName bool
finalinherited
showSearchInput bool
finalinherited
useRootNavigator bool
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestCountrySelector(BuildContext context) Future<Country?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited