addFavouriteSeparator property
Whether to add a list divider between favorites & defaults countries.
Implementation
final bool addFavouriteSeparator;
Whether to add a list divider between favorites & defaults countries.
final bool addFavouriteSeparator;