isBottomSheet property
Determines if the component is being used within a bottom sheet. For display bottomSheetDragHandler and some paddings
Implementation
final bool isBottomSheet;
Determines if the component is being used within a bottom sheet. For display bottomSheetDragHandler and some paddings
final bool isBottomSheet;