CountrySelectorNavigator class abstract

Implementers

Constructors

CountrySelectorNavigator({List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator = true, bool showCountryCode = true, String? noResultMessage, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, TextStyle? searchInputTextStyle, Color? defaultSearchInputIconColor, InputDecoration? searchInputDecoration, ScrollPhysics? scrollPhysics, BoxShape flagShape = BoxShape.circle, double flagSize = 48, bool useRootNavigator = true, bool showCountryName = true, bool showCountryFlag = true, bool showSearchInput = true, Color? bottomSheetDragHandlerColor, double? searchInputWidth, double? searchInputHeight})
const
CountrySelectorNavigator.bottomSheet({List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator, bool showCountryCode, String? noResultMessage, bool showSearchInput, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, InputDecoration? searchInputDecoration, TextStyle? searchInputTextStyle, Color? defaultSearchInputIconColor, Color? bottomSheetDragHandlerColor, ScrollPhysics? scrollPhysics, double flagSize, BoxShape flagShape, bool showCountryName, bool showCountryFlag, double? searchInputHeight, double? searchInputWidth})
const
factory
CountrySelectorNavigator.dialog({double? height, double? width, List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator, bool showCountryCode, String? noResultMessage, bool showSearchInput, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, InputDecoration? searchInputDecoration, TextStyle? searchInputTextStyle, Color? defaultSearchInputIconColor, ScrollPhysics? scrollPhysics, double flagSize, BoxShape flagShape, bool showCountryName, bool showCountryFlag, double? searchInputHeight, double? searchInputWidth})
const
factory
CountrySelectorNavigator.draggableBottomSheet({double initialChildSize, double minChildSize, double maxChildSize, BorderRadiusGeometry? borderRadius, List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator, bool showCountryCode, double flagSize, String? noResultMessage, bool showSearchInput, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, InputDecoration? searchInputDecoration, TextStyle? searchInputTextStyle, Color? defaultSearchInputIconColor, Color? bottomSheetDragHandlerColor, ScrollPhysics? scrollPhysics, BoxShape flagShape, bool showCountryName, bool showCountryFlag, double? searchInputHeight, double? searchInputWidth})
const
factory
CountrySelectorNavigator.dropdown({required LayerLink layerLink, BorderRadiusGeometry? borderRadius, double listHeight, Color? backgroundColor, List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator, bool showCountryCode, bool showSearchInput, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, ScrollPhysics? scrollPhysics, double flagSize, BoxShape flagShape, double? offsetHeight, bool showCountryName, bool showCountryFlag, String? noResultMessage, InputDecoration? searchInputDecoration, TextStyle? searchInputTextStyle, Color? defaultSearchInputIconColor, bool useRootNavigator, double? searchInputHeight, double? searchInputWidth})
const
factory
CountrySelectorNavigator.modalBottomSheet({double? height, List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator, bool showCountryCode, String? noResultMessage, bool showSearchInput, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, InputDecoration? searchInputDecoration, TextStyle? searchInputTextStyle, Color? defaultSearchInputIconColor, Color? bottomSheetDragHandlerColor, ScrollPhysics? scrollPhysics, double flagSize, BoxShape flagShape, bool showCountryName, bool showCountryFlag, double? searchInputHeight, double? searchInputWidth})
const
factory
CountrySelectorNavigator.searchDelegate({List<IsoCode>? countries, List<IsoCode>? favorites, bool addFavoriteSeparator, bool showCountryCode, String? noResultMessage, TextStyle? countryCodeStyle, TextStyle? countryNameStyle, ScrollPhysics? scrollPhysics, double flagSize, BoxShape flagShape, bool showCountryName, bool showCountryFlag})
const
factory

Properties

addFavoriteSeparator → bool
final
bottomSheetDragHandlerColor → Color?
final
countries → List<IsoCode>?
final
countryCodeStyle → TextStyle?
final
countryNameStyle → TextStyle?
final
defaultSearchInputIconColor → Color?
final
favorites → List<IsoCode>?
final
flagShape → BoxShape
final
flagSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
noResultMessage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics → ScrollPhysics?
final
searchInputDecoration → InputDecoration?
final
searchInputHeight → double?
final
searchInputTextStyle → TextStyle?
final
searchInputWidth → double?
final
showCountryCode → bool
final
showCountryFlag → bool
final
showCountryName → bool
final
showSearchInput → bool
final
useRootNavigator → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestCountrySelector(BuildContext context) → Future<Country?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited