shouldFormat property

bool shouldFormat
final

Specify whether the field will format the national number with shouldFormat = true (default) eg: +33677784455 will be displayed as +33 6 77 78 44 55.

The formats are localized for the country code. eg: +1 677-784-455 & +33 6 77 78 44 55

This does not affect the output value, only the display. Therefor onSizeFound will still return a PhoneNumber with nsn of 677784455.

Implementation

final bool shouldFormat;