CountryCodeChip class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CountryCodeChip
Constructors
- CountryCodeChip({Key? key, required IsoCode isoCode, TextStyle countryCodeTextStyle = const TextStyle(), bool showFlag = true, double flagSize = 20, BoxShape flagShape = BoxShape.circle, TextDirection? textDirection, bool showArrow = true, bool isListVisible = false})
Properties
- country → Country
-
The country associated with the component.
final
- countryCodeTextStyle → TextStyle
-
TextStyle for customizing the appearance of the country code.
final
- flagShape → BoxShape
-
Determines if the displayed flags should be circular.
final
- flagSize → double
-
The size factor for displaying flags within the UI.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isListVisible → bool
-
Determines if the list is visible.
Changing this variable reproduces the arrow animation
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
Determines if an arrow indicator should be displayed.
final
- showFlag → bool
-
Determines if the country flag should be displayed.
final
- textDirection → TextDirection?
-
The direction of the text within the component.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited